==> netbeans_8.0.2+dfsg1.orig.tar.xz: netbeans-8.0.2/cnd.repository.api/src/org/netbeans/modules/cnd/repository/impl/ShuttedDownRepositoryImpl.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2013 Sun Microsystems, Inc.
 */
package org.netbeans.modules.cnd.repository.impl;

import java.util.Set;
import org.netbeans.modules.cnd.repository.api.UnitDescriptor;
import org.netbeans.modules.cnd.repository.impl.spi.LayeringSupport;
import org.netbeans.modules.cnd.repository.impl.spi.RepositoryImplementation;
import org.netbeans.modules.cnd.repository.spi.Key;
import org.netbeans.modules.cnd.repository.spi.Persistent;

/**
 *
 * @author akrasny
 */
public final class ShuttedDownRepositoryImpl implements RepositoryImplementation {

    private final String msg;

    public ShuttedDownRepositoryImpl(String msg) {
        this.msg = msg;
    }

    @Override
    public Persistent get(Key key) {
        return null;
    }

    @Override
    public void put(Key key, Persistent obj) {
    }

    @Override
    public void remove(Key key) {
    }

    @Override
    public void shutdown() {
    }

    @Override
    public void closeUnit(int unitId, boolean cleanRepository, Set<Integer> requiredUnits) {
    }

    @Override
    public void openUnit(int unitId) {
    }

    @Override
    public void removeUnit(int unitId) {
    }

    @Override
    public void hang(Key key, Persistent obj) {
    }

    @Override
    public void debugDistribution() {
    }

    @Override
    public void debugDump(Key key) {
    }

    @Override
    public int getFileIdByName(int unitId, CharSequence fileName) {
        return -1;
    }

    @Override
    public CharSequence getFileNameById(int unitId, int fileId) {
        return null;
    }

    @Override
    public CharSequence getFileNameByIdSafe(int unitId, int fileId) {
        return null;
    }

    @Override
    public CharSequence getUnitName(int unitId) {
        return null;
    }

    @Override
    public int getUnitID(UnitDescriptor unitDescriptor, int sourceUnitId) {
        return -1;
    }

    @Override
    public int getUnitID(UnitDescriptor unitDescriptor) {
        return -1;
    }

    @Override
    public int getRepositoryID(int sourceUnitId) {
        return -1;
    }

    @Override
    public LayeringSupport getLayeringSupport(int clientUnitID) {
        return null;
    }
}

==> netbeans_8.1+dfsg2.orig.tar.xz: netbeans-8.1/cnd.repository.api/src/org/netbeans/modules/cnd/repository/impl/ShuttedDownRepositoryImpl.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2013 Sun Microsystems, Inc.
 */
package org.netbeans.modules.cnd.repository.impl;

import java.util.Set;
import org.netbeans.modules.cnd.repository.api.UnitDescriptor;
import org.netbeans.modules.cnd.repository.impl.spi.LayeringSupport;
import org.netbeans.modules.cnd.repository.impl.spi.RepositoryImplementation;
import org.netbeans.modules.cnd.repository.spi.Key;
import org.netbeans.modules.cnd.repository.spi.Persistent;

/**
 *
 * @author akrasny
 */
public final class ShuttedDownRepositoryImpl implements RepositoryImplementation {

    private final String msg;

    public ShuttedDownRepositoryImpl(String msg) {
        this.msg = msg;
    }

    @Override
    public Persistent get(Key key) {
        return null;
    }

    @Override
    public void put(Key key, Persistent obj) {
    }

    @Override
    public void remove(Key key) {
    }

    @Override
    public void shutdown() {
    }

    @Override
    public void closeUnit(int unitId, boolean cleanRepository, Set<Integer> requiredUnits) {
    }

    @Override
    public void openUnit(int unitId) {
    }

    @Override
    public void removeUnit(int unitId) {
    }

    @Override
    public void hang(Key key, Persistent obj) {
    }

    @Override
    public void debugDistribution() {
    }

    @Override
    public void debugDump(Key key) {
    }

    @Override
    public int getFileIdByName(int unitId, CharSequence fileName) {
        return -1;
    }

    @Override
    public CharSequence getFileNameById(int unitId, int fileId) {
        return null;
    }

    @Override
    public CharSequence getFileNameByIdSafe(int unitId, int fileId) {
        return null;
    }

    @Override
    public CharSequence getUnitName(int unitId) {
        return null;
    }

    @Override
    public int getUnitID(UnitDescriptor unitDescriptor, int storageID) {
        return -1;
    }

    @Override
    public int getUnitID(UnitDescriptor unitDescriptor) {
        return -1;
    }

    @Override
    public int getRepositoryID(int sourceUnitId) {
        return -1;
    }

    @Override
    public LayeringSupport getLayeringSupport(int clientUnitID) {
        return null;
    }
}
